@@ -1,22 +1,35 @@
 from mongoengine import *
+from enum import Enum
 
-ORDER_BY_VALUES = (
-    'asc',
-    'desc'
-)
 
-ENTITIES = (
-    'prices',
-    'transactions'
-)
+class ORDER_BY_VALUES(Enum):
+    ASC = 1
+    DESC = 2
 
-AGGREGATE_TYPES = (
-    'SUM',
-    'MAX',
-    'AVG',
-    'MIN',
-    ''
-)
+    @classmethod
+    def choices(cls):
+        return tuple((i.name, i.value) for i in cls)
+
+
+class ENTITIES(Enum):
+    prices = 1
+    transactions = 2
+
+    @classmethod
+    def choices(cls):
+        return tuple((i.name, i.value) for i in cls)
+
+
+class AGGREGATE_TYPES(Enum):
+    SUM = 1
+    MAX = 2
+    AVG = 3
+    MIN = 4
+    NONE = 5
+
+    @classmethod
+    def choices(cls):
+        return tuple((i.name, i.value) for i in cls)
 
 
 class filterItem(Document):
@@ -43,13 +56,10 @@ ordered by dt desc
 class query(Document):
     meta = {'strict': False}
     name = StringField()
-    entity_name = StringField(choices=ENTITIES)
-
+    entity_name = StringField(choices=ENTITIES.choices())
     filters = ListField(EmbeddedDocumentListField(filterItem, db_field='filters'))
-
     orderByItems = ListField(EmbeddedDocumentListField(orderByItem, db_field='orderByItems'))
-
     is_top = BooleanField()
     top_value = IntField()
     applies_aggregate = BooleanField()
-    aggregate_type = StringField(choices=AGGREGATE_TYPES)
+    aggregate_type = StringField(choices=AGGREGATE_TYPES.choices())
